@@ -71,6 +71,7 @@ class VaeImageProcessor(ConfigMixin):
         self,
         do_resize: bool = True,
         vae_scale_factor: int = 8,
+        vae_latent_channels: int = 4,
         resample: str = "lanczos",
         do_normalize: bool = True,
         do_binarize: bool = False,
@@ -348,6 +349,10 @@ class VaeImageProcessor(ConfigMixin):
         if self.config.do_binarize:
             image = self.binarize(image)
 
+        # laixinlu: add this, for paddle not auto support float32 * bool
+        if isinstance(image, paddle.Tensor) and image.dtype == paddle.bool:
+            image = image.cast(dtype="float32")
+            
         return image
 
     def postprocess(
