@@ -334,6 +334,10 @@ class CMStochasticIterativeScheduler(SchedulerMixin, ConfigMixin):
         sigma_min = self.config.sigma_min
         sigma_max = self.config.sigma_max
 
+        # NOTE(laixinlu) convert sigmas to the dtype of the model output
+        if self.sigmas.dtype != model_output.dtype:
+            self.sigmas = self.sigmas.cast(model_output.dtype)
+
         if self.step_index is None:
             self._init_step_index(timestep)
 
