@@ -16,7 +16,7 @@
 import contextlib
 import copy
 import random
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, Optional, Union, List
 
 import numpy as np
 import paddle
@@ -87,6 +87,16 @@ def unet_lora_state_dict(unet: UNet2DConditionModel) -> Dict[str, paddle.Tensor]
     return lora_state_dict
 
 
+def cast_training_params(model: Union[paddle.nn.Layer, List[paddle.nn.Layer]], dtype=paddle.float32):
+    if not isinstance(model, list):
+        model = [model]
+    for m in model:
+        for param in m.parameters():
+            # only upcast trainable parameters into fp32
+            if param.stop_gradient == False:
+                param.set_value(paddle.cast(param, dtype))
+
+
 # Adapted from torch-ema https://github.com/fadel/pytorch_ema/blob/master/torch_ema/ema.py#L14
 class EMAModel:
     """
@@ -422,4 +432,4 @@ def unwrap_model(model: nn.Layer) -> nn.Layer:
     if hasattr(model, "_layers"):
         return unwrap_model(model._layers)
     else:
-        return model
+        return model
\ No newline at end of file
