@@ -1,5 +1,6 @@
+# coding=utf-8
 # Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
-# Copyright 2023 The HuggingFace Team. All rights reserved.
+# Copyright 2023 HuggingFace Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,8 +21,14 @@ import unittest
 import paddle
 
 from ppdiffusers import UNet2DModel
-from ppdiffusers.utils import floats_tensor, logging, paddle_all_close, slow
-from ppdiffusers.utils.testing_utils import enable_full_determinism
+from ppdiffusers.utils import logging
+from ppdiffusers.utils.testing_utils import (
+    enable_full_determinism,
+    floats_tensor,
+    paddle_all_close,
+    paddle_device,
+    slow,
+)
 
 from .test_modeling_common import ModelTesterMixin, UNetTesterMixin
 
@@ -39,8 +46,10 @@ class Unet2DModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
         batch_size = 4
         num_channels = 3
         sizes = 32, 32
+
         noise = floats_tensor((batch_size, num_channels) + sizes)
         time_step = paddle.to_tensor([10])
+
         return {"sample": noise, "timestep": time_step}
 
     @property
@@ -65,6 +74,35 @@ class Unet2DModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
         inputs_dict = self.dummy_input
         return init_dict, inputs_dict
 
+    def test_mid_block_attn_groups(self):
+        init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
+
+        init_dict["norm_num_groups"] = 16
+        init_dict["add_attention"] = True
+        init_dict["attn_norm_num_groups"] = 8
+
+        model = self.model_class(**init_dict)
+        model.eval()
+
+        self.assertIsNotNone(
+            model.mid_block.attentions[0].group_norm, "Mid block Attention group norm should exist but does not."
+        )
+        self.assertEqual(
+            model.mid_block.attentions[0].group_norm._num_groups,
+            init_dict["attn_norm_num_groups"],
+            "Mid block Attention group norm does not have the expected number of groups.",
+        )
+
+        with paddle.no_grad():
+            output = model(**inputs_dict)
+
+            if isinstance(output, dict):
+                output = output.to_tuple()[0]
+
+        self.assertIsNotNone(output)
+        expected_shape = inputs_dict["sample"].shape
+        self.assertEqual(output.shape, expected_shape, "Input and output shapes do not match")
+
 
 class UNetLDMModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
     model_class = UNet2DModel
@@ -75,8 +113,10 @@ class UNetLDMModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
         batch_size = 4
         num_channels = 4
         sizes = 32, 32
+
         noise = floats_tensor((batch_size, num_channels) + sizes)
         time_step = paddle.to_tensor([10])
+
         return {"sample": noise, "timestep": time_step}
 
     @property
@@ -103,21 +143,30 @@ class UNetLDMModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
 
     def test_from_pretrained_hub(self):
         model, loading_info = UNet2DModel.from_pretrained("fusing/unet-ldm-dummy-update", output_loading_info=True)
+
         self.assertIsNotNone(model)
         self.assertEqual(len(loading_info["missing_keys"]), 0)
+
         image = model(**self.dummy_input).sample
+
         assert image is not None, "Make sure output is not None"
 
+    @unittest.skipIf(paddle_device != "cuda", "This test is supposed to run on GPU")
     def test_from_pretrained_accelerate(self):
         model, _ = UNet2DModel.from_pretrained("fusing/unet-ldm-dummy-update", output_loading_info=True)
         image = model(**self.dummy_input).sample
+
         assert image is not None, "Make sure output is not None"
 
+    @unittest.skipIf(paddle_device != "cuda", "This test is supposed to run on GPU")
     def test_from_pretrained_accelerate_wont_change_results(self):
+        # by defautl model loading will use accelerate as `low_cpu_mem_usage=True`
         model_accelerate, _ = UNet2DModel.from_pretrained("fusing/unet-ldm-dummy-update", output_loading_info=True)
+        # model_accelerate
         model_accelerate.eval()
+
         noise = paddle.randn(
-            shape=[
+            [
                 1,
                 model_accelerate.config.in_channels,
                 model_accelerate.config.sample_size,
@@ -126,29 +175,37 @@ class UNetLDMModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
             generator=paddle.Generator().manual_seed(0),
         )
         time_step = paddle.to_tensor([10] * noise.shape[0])
+
         arr_accelerate = model_accelerate(noise, time_step)["sample"]
+
+        # two models don't need to stay in the device at the same time
         del model_accelerate
         paddle.device.cuda.empty_cache()
         gc.collect()
+
         model_normal_load, _ = UNet2DModel.from_pretrained(
-            "fusing/unet-ldm-dummy-update",
-            output_loading_info=True,
+            "fusing/unet-ldm-dummy-update", output_loading_info=True, low_cpu_mem_usage=False
         )
         model_normal_load.eval()
         arr_normal_load = model_normal_load(noise, time_step)["sample"]
-        assert paddle_all_close(arr_accelerate, arr_normal_load, rtol=0.001)
+
+        assert paddle_all_close(arr_accelerate, arr_normal_load, rtol=1e-3)
 
     def test_output_pretrained(self):
         model = UNet2DModel.from_pretrained("fusing/unet-ldm-dummy-update")
         model.eval()
+
         noise = paddle.randn(
             shape=[1, model.config.in_channels, model.config.sample_size, model.config.sample_size],
             generator=paddle.Generator().manual_seed(0),
         )
         time_step = paddle.to_tensor([10] * noise.shape[0])
+
         with paddle.no_grad():
             output = model(noise, time_step).sample
+
         output_slice = output[0, -1, -3:, -3:].flatten().cpu()
+        # fmt: off
         expected_output_slice = paddle.to_tensor(
             [
                 0.43855608,
@@ -162,7 +219,9 @@ class UNetLDMModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
                 -10.52999401,
             ]
         )
-        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=0.001))
+        # fmt: on
+
+        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=1e-3))
 
 
 class NCSNppModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
@@ -173,8 +232,10 @@ class NCSNppModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
     def dummy_input(self, sizes=(32, 32)):
         batch_size = 4
         num_channels = 3
+
         noise = floats_tensor((batch_size, num_channels) + sizes)
         time_step = paddle.to_tensor(batch_size * [10]).cast("int32")
+
         return {"sample": noise, "timestep": time_step}
 
     @property
@@ -192,11 +253,21 @@ class NCSNppModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
             "layers_per_block": 1,
             "out_channels": 3,
             "time_embedding_type": "fourier",
-            "norm_eps": 1e-06,
+            "norm_eps": 1e-6,
             "mid_block_scale_factor": math.sqrt(2.0),
             "norm_num_groups": None,
-            "down_block_types": ["SkipDownBlock2D", "AttnSkipDownBlock2D", "SkipDownBlock2D", "SkipDownBlock2D"],
-            "up_block_types": ["SkipUpBlock2D", "SkipUpBlock2D", "AttnSkipUpBlock2D", "SkipUpBlock2D"],
+            "down_block_types": [
+                "SkipDownBlock2D",
+                "AttnSkipDownBlock2D",
+                "SkipDownBlock2D",
+                "SkipDownBlock2D",
+            ],
+            "up_block_types": [
+                "SkipUpBlock2D",
+                "SkipUpBlock2D",
+                "AttnSkipUpBlock2D",
+                "SkipUpBlock2D",
+            ],
         }
         inputs_dict = self.dummy_input
         return init_dict, inputs_dict
@@ -206,44 +277,55 @@ class NCSNppModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
         model, loading_info = UNet2DModel.from_pretrained("google/ncsnpp-celebahq-256", output_loading_info=True)
         self.assertIsNotNone(model)
         self.assertEqual(len(loading_info["missing_keys"]), 0)
+
         inputs = self.dummy_input
         noise = floats_tensor((4, 3) + (256, 256))
         inputs["sample"] = noise
         image = model(**inputs)
+
         assert image is not None, "Make sure output is not None"
 
     @slow
     def test_output_pretrained_ve_mid(self):
         model = UNet2DModel.from_pretrained("google/ncsnpp-celebahq-256")
-        paddle.seed(0)
+
         batch_size = 4
         num_channels = 3
         sizes = 256, 256
-        noise = paddle.ones(shape=(batch_size, num_channels, *sizes))
-        time_step = paddle.to_tensor(batch_size * [0.0001])
+
+        noise = paddle.ones((batch_size, num_channels, *sizes))
+        time_step = paddle.to_tensor(batch_size * [1e-4])
+
         with paddle.no_grad():
             output = model(noise, time_step).sample
+
         output_slice = output[0, -3:, -3:, -1].flatten().cpu()
-        expected_output_slice = paddle.to_tensor(
-            [-4836.2231, -6487.1387, -3816.7969, -7964.9253, -10966.2842, -20043.6016, 8137.0571, 2340.3499, 544.6114]
-        )
-        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=0.01))
+        # fmt: off
+        expected_output_slice = paddle.to_tensor([-4836.2178, -6487.1470, -3816.8196, -7964.9302, -10966.3037, -20043.5957, 8137.0513, 2340.3328, 544.6056])
+        # fmt: on
+
+        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=1e-2))
 
     def test_output_pretrained_ve_large(self):
         model = UNet2DModel.from_pretrained("fusing/ncsnpp-ffhq-ve-dummy-update")
-        paddle.seed(0)
+
         batch_size = 4
         num_channels = 3
         sizes = 32, 32
-        noise = paddle.ones(shape=(batch_size, num_channels, *sizes))
-        time_step = paddle.to_tensor(batch_size * [0.0001])
+
+        noise = paddle.ones((batch_size, num_channels, *sizes))
+        time_step = paddle.to_tensor(batch_size * [1e-4])
+
         with paddle.no_grad():
             output = model(noise, time_step).sample
+
         output_slice = output[0, -3:, -3:, -1].flatten().cpu()
-        expected_output_slice = paddle.to_tensor(
-            [-0.0325, -0.09, -0.0869, -0.0332, -0.0725, -0.027, -0.0101, 0.0227, 0.0256]
-        )
-        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=0.01))
+        # fmt: off
+        expected_output_slice = paddle.to_tensor([-0.0325, -0.0900, -0.0869, -0.0332, -0.0725, -0.0270, -0.0101, 0.0227, 0.0256])
+        # fmt: on
+
+        self.assertTrue(paddle_all_close(output_slice, expected_output_slice, rtol=1e-2))
 
     def test_forward_with_norm_groups(self):
+        # not required for this model
         pass
