@@ -1,5 +1,5 @@
 # Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
-# Copyright 2023 The HuggingFace Team. All rights reserved.
+# Copyright 2023 HuggingFace Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,28 +15,43 @@
 
 import gc
 import random
+import traceback
 import unittest
 
 import numpy as np
 import paddle
-from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel, CLIPTokenizer
 
-from ppdiffusers import (
+from ppdiffusers import (  # HeunDiscreteScheduler,
     AutoencoderKL,
+    AutoencoderTiny,
     DDIMScheduler,
     DPMSolverMultistepScheduler,
+    LCMScheduler,
     LMSDiscreteScheduler,
     PNDMScheduler,
-    StableDiffusionImg2ImgPipeline,
     UNet2DConditionModel,
 )
-from ppdiffusers.utils import floats_tensor, load_image, load_numpy, nightly, slow
-from ppdiffusers.utils.testing_utils import enable_full_determinism, require_paddle_gpu
+from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion_img2img import (
+    StableDiffusionImg2ImgPipeline,
+)
+from ppdiffusers.transformers import CLIPTextConfig, CLIPTextModel, CLIPTokenizer
+from ppdiffusers.utils.testing_utils import (  # skip_mps,
+    enable_full_determinism,
+    floats_tensor,
+    load_image,
+    load_numpy,
+    nightly,
+    require_paddle_gpu,
+    require_python39_or_higher,
+    run_test_in_subprocess,
+    slow,
+)
 
 from ..pipeline_params import (
     IMAGE_TO_IMAGE_IMAGE_PARAMS,
     TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS,
     TEXT_GUIDED_IMAGE_VARIATION_PARAMS,
+    TEXT_TO_IMAGE_CALLBACK_CFG_PARAMS,
 )
 from ..test_pipelines_common import (
     PipelineKarrasSchedulerTesterMixin,
@@ -47,6 +62,34 @@ from ..test_pipelines_common import (
 enable_full_determinism()
 
 
+# Will be run via run_test_in_subprocess
+def _test_img2img_compile(in_queue, out_queue, timeout):
+    error = None
+    try:
+        inputs = in_queue.get(timeout=timeout)
+        seed = inputs.pop("seed")
+        inputs["generator"] = paddle.Generator(device="gpu").manual_seed(seed)
+
+        pipe = StableDiffusionImg2ImgPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
+        pipe.scheduler = DDIMScheduler.from_config(pipe.scheduler.config)
+        pipe.unet.set_default_attn_processor()
+        pipe.set_progress_bar_config(disable=None)
+
+        image = pipe(**inputs).images
+        image_slice = image[0, -3:, -3:, -1].flatten()
+
+        assert image.shape == (1, 512, 768, 3)
+        expected_slice = np.array([0.0606, 0.0570, 0.0805, 0.0579, 0.0628, 0.0623, 0.0843, 0.1115, 0.0806])
+
+        assert np.abs(expected_slice - image_slice).max() < 1e-3
+    except Exception:
+        error = f"{traceback.format_exc()}"
+
+    results = {"error": error}
+    out_queue.put(results, timeout=timeout)
+    out_queue.join()
+
+
 class StableDiffusionImg2ImgPipelineFastTests(
     PipelineLatentTesterMixin, PipelineKarrasSchedulerTesterMixin, PipelineTesterMixin, unittest.TestCase
 ):
@@ -56,12 +99,14 @@ class StableDiffusionImg2ImgPipelineFastTests(
     batch_params = TEXT_GUIDED_IMAGE_VARIATION_BATCH_PARAMS
     image_params = IMAGE_TO_IMAGE_IMAGE_PARAMS
     image_latents_params = IMAGE_TO_IMAGE_IMAGE_PARAMS
+    callback_cfg_params = TEXT_TO_IMAGE_CALLBACK_CFG_PARAMS
 
-    def get_dummy_components(self):
+    def get_dummy_components(self, time_cond_proj_dim=None):
         paddle.seed(0)
         unet = UNet2DConditionModel(
             block_out_channels=(32, 64),
             layers_per_block=2,
+            time_cond_proj_dim=time_cond_proj_dim,
             sample_size=32,
             in_channels=4,
             out_channels=4,
@@ -91,8 +136,9 @@ class StableDiffusionImg2ImgPipelineFastTests(
             pad_token_id=1,
             vocab_size=1000,
         )
-        text_encoder = CLIPTextModel(text_encoder_config).eval()
+        text_encoder = CLIPTextModel(text_encoder_config)
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -101,91 +147,183 @@ class StableDiffusionImg2ImgPipelineFastTests(
             "tokenizer": tokenizer,
             "safety_checker": None,
             "feature_extractor": None,
+            "image_encoder": None,
         }
         return components
 
-    def get_dummy_inputs(self, seed=0):
+    def get_dummy_tiny_autoencoder(self):
+        return AutoencoderTiny(in_channels=3, out_channels=3, latent_channels=4)
+
+    def get_dummy_inputs(self, device="gpu", seed=0):
         image = floats_tensor((1, 3, 32, 32), rng=random.Random(seed))
         image = image / 2 + 0.5
-        generator = paddle.Generator().manual_seed(seed)
-
+        if str(device).startswith("mps"):
+            generator = paddle.seed(seed)
+        else:
+            generator = paddle.Generator(device=device).manual_seed(seed)
         inputs = {
             "prompt": "A painting of a squirrel eating a burger",
             "image": image,
             "generator": generator,
             "num_inference_steps": 2,
             "guidance_scale": 6.0,
-            "output_type": "np",
+            "output_type": "numpy",
         }
         return inputs
 
     def test_stable_diffusion_img2img_default_case(self):
+        device = "cpu"  # ensure determinism for the device-dependent paddle.Generator
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionImg2ImgPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
-        inputs = self.get_dummy_inputs()
+
+        inputs = self.get_dummy_inputs(device)
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
+
         assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.4555, 0.3216, 0.4049, 0.4620, 0.4618, 0.4126, 0.4122, 0.4629, 0.4579])
         expected_slice = np.array([1.000, 0.6866, 0.6297, 0.6039, 0.4147, 0.5347, 0.7396, 0.6176, 0.6515])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-3
+
+    def test_stable_diffusion_img2img_default_case_lcm(self):
+        device = "cpu"  # ensure determinism for the device-dependent paddle.Generator
+        components = self.get_dummy_components(time_cond_proj_dim=256)
+        sd_pipe = StableDiffusionImg2ImgPipeline(**components)
+        sd_pipe.scheduler = LCMScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe.set_progress_bar_config(disable=None)
+
+        inputs = self.get_dummy_inputs(device)
+        image = sd_pipe(**inputs).images
+        image_slice = image[0, -3:, -3:, -1]
+
+        assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.5709, 0.4614, 0.4587, 0.5978, 0.5298, 0.6910, 0.6240, 0.5212, 0.5454])
+        expected_slice = np.array(
+            [0.85502994, 0.9199225, 0.4495193, 0.6851815, 0.6132464, 0.34710735, 0.6529883, 0.54201126, 0.36325687]
+        )
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-3
+
+    def test_stable_diffusion_img2img_default_case_lcm_custom_timesteps(self):
+        device = "cpu"  # ensure determinism for the device-dependent paddle.Generator
+        components = self.get_dummy_components(time_cond_proj_dim=256)
+        sd_pipe = StableDiffusionImg2ImgPipeline(**components)
+        sd_pipe.scheduler = LCMScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe.set_progress_bar_config(disable=None)
+
+        inputs = self.get_dummy_inputs(device)
+        del inputs["num_inference_steps"]
+        inputs["timesteps"] = [999, 499]
+        image = sd_pipe(**inputs).images
+        image_slice = image[0, -3:, -3:, -1]
+
+        assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.5709, 0.4614, 0.4587, 0.5978, 0.5298, 0.6910, 0.6240, 0.5212, 0.5454])
+        expected_slice = np.array(
+            [
+                [0.85503006, 0.91992253, 0.4495193],
+                [0.6851816, 0.6132464, 0.34710735],
+                [0.6529883, 0.54201126, 0.36325687],
+            ]
+        )
+
+        assert np.abs(image_slice.flatten() - expected_slice.flatten()).max() < 1e-3
 
     def test_stable_diffusion_img2img_negative_prompt(self):
+        device = "gpu"  # ensure determinism for the device-dependent paddle.Generator
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionImg2ImgPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
-        inputs = self.get_dummy_inputs()
+
+        inputs = self.get_dummy_inputs(device)
         negative_prompt = "french fries"
         output = sd_pipe(**inputs, negative_prompt=negative_prompt)
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
+
         assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.4593, 0.3408, 0.4232, 0.4749, 0.4476, 0.4115, 0.4357, 0.4733, 0.4663])
         expected_slice = np.array([0.8129, 0.6052, 0.5828, 0.4865, 0.505, 0.5728, 0.5985, 0.5965, 0.6619])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-3
 
     def test_stable_diffusion_img2img_multiple_init_images(self):
+        device = "cpu"  # ensure determinism for the device-dependent paddle.Generator
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionImg2ImgPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
-        inputs = self.get_dummy_inputs()
+
+        inputs = self.get_dummy_inputs(device)
         inputs["prompt"] = [inputs["prompt"]] * 2
-        inputs["image"] = inputs["image"].tile(repeat_times=[2, 1, 1, 1])
+        inputs["image"] = inputs["image"].tile([2, 1, 1, 1])
         image = sd_pipe(**inputs).images
         image_slice = image[-1, -3:, -3:, -1]
+
         assert image.shape == (2, 32, 32, 3)
+        # expected_slice = np.array([0.4241, 0.5576, 0.5711, 0.4792, 0.4311, 0.5952, 0.5827, 0.5138, 0.5109])
         expected_slice = np.array([0.4915, 0.2387, 0.6499, 0.7189, 0.3702, 0.5765, 0.7953, 0.6532, 0.6312])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-3
 
     def test_stable_diffusion_img2img_k_lms(self):
+        device = "cpu"  # ensure determinism for the device-dependent paddle.Generator
         components = self.get_dummy_components()
         components["scheduler"] = LMSDiscreteScheduler(
             beta_start=0.00085, beta_end=0.012, beta_schedule="scaled_linear"
         )
         sd_pipe = StableDiffusionImg2ImgPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
-        inputs = self.get_dummy_inputs()
+
+        inputs = self.get_dummy_inputs(device)
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
+
         assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.4398, 0.4949, 0.4337, 0.6580, 0.5555, 0.4338, 0.5769, 0.5955, 0.5175])
         expected_slice = np.array([0.1131, 0.7903, 0.67949, 0.1962, 0.8975, 0.4891, 0.4096, 0.6387, 0.4599])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-3
+
+    def test_stable_diffusion_img2img_tiny_autoencoder(self):
+        device = "gpu"  # ensure determinism for the device-dependent paddle.Generator
+        components = self.get_dummy_components()
+        sd_pipe = StableDiffusionImg2ImgPipeline(**components)
+        sd_pipe.vae = self.get_dummy_tiny_autoencoder()
+        sd_pipe.set_progress_bar_config(disable=None)
+
+        inputs = self.get_dummy_inputs(device)
+        image = sd_pipe(**inputs).images
+        image_slice = image[0, -3:, -3:, -1]
+
+        assert image.shape == (1, 32, 32, 3)
+        # expected_slice = np.array([0.00669, 0.00669, 0.0, 0.00693, 0.00858, 0.0, 0.00567, 0.00515, 0.00125])
+        expected_slice = np.array([[0.0, 0.0, 0.0], [0.0, 0.0, 1.0], [0.0, 0.0, 0.0]])
+
+        assert np.abs(image_slice.flatten() - expected_slice.flatten()).max() < 1e-3
+
+    # @skip_mps
+    def test_save_load_local(self):
+        return super().test_save_load_local()
+
+    # @skip_mps
+    def test_dict_tuple_outputs_equivalent(self):
+        return super().test_dict_tuple_outputs_equivalent()
+
+    # @skip_mps
+    def test_save_load_optional_components(self):
+        return super().test_save_load_optional_components()
+
+    # @skip_mps
+    def test_attention_slicing_forward_pass(self):
+        return super().test_attention_slicing_forward_pass(expected_max_diff=5e-3)
 
     def test_inference_batch_single_identical(self):
-        super().test_inference_batch_single_identical()
+        super().test_inference_batch_single_identical(expected_max_diff=3e-3)
 
-    def test_pd_np_pil_inputs_equivalent(self):
-        if len(self.image_params) == 0:
-            return
-        components = self.get_dummy_components()
-        pipe = self.pipeline_class(**components)
-        pipe.set_progress_bar_config(disable=None)
-        out_input_pd = pipe(**self.get_dummy_inputs_by_type(input_image_type="pd"))[0]
-        out_input_np = pipe(**self.get_dummy_inputs_by_type(input_image_type="np"))[0]
-        out_input_pil = pipe(**self.get_dummy_inputs_by_type(input_image_type="pil"))[0]
-        max_diff = np.abs(out_input_pd - out_input_np).max()
-        self.assertLess(max_diff, 0.0001, "`input_type=='pd'` generate different result from `input_type=='np'`")
-        max_diff = np.abs(out_input_pil - out_input_np).max()
-        self.assertLess(max_diff, 0.04, "`input_type=='pd'` generate different result from `input_type=='np'`")
+    def test_float16_inference(self):
+        super().test_float16_inference(expected_max_diff=5e-1)
 
 
 @slow
@@ -210,80 +348,55 @@ class StableDiffusionImg2ImgPipelineSlowTests(unittest.TestCase):
         }
         return inputs
 
-    # def test_img2img_2nd_order(self):
-    #     sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
-    #     sd_pipe.scheduler = HeunDiscreteScheduler.from_config(sd_pipe.scheduler.config)
-    #     sd_pipe.set_progress_bar_config(disable=None)
-
-    #     inputs = self.get_inputs()
-    #     inputs["num_inference_steps"] = 10
-    #     inputs["strength"] = 0.75
-    #     image = sd_pipe(**inputs).images[0]
-
-    #     expected_image = load_numpy(
-    #         "https://paddlenlp.bj.bcebos.com/data/images/img2img_heun.npy"
-    #     )
-    #     max_diff = np.abs(expected_image - image).max()
-    #     assert max_diff < 5e-2
-
-    #     inputs = self.get_inputs()
-    #     inputs["num_inference_steps"] = 11
-    #     inputs["strength"] = 0.75
-    #     image_other = sd_pipe(**inputs).images[0]
-
-    #     mean_diff = np.abs(image - image_other).mean()
-
-    #     # images should be very similar
-    #     assert mean_diff < 5e-2
-
     def test_stable_diffusion_img2img_default(self):
         pipe = StableDiffusionImg2ImgPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
+
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
+
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
+
         assert image.shape == (1, 512, 768, 3)
+        # expected_slice = np.array([0.4300, 0.4662, 0.4930, 0.3990, 0.4307, 0.4525, 0.3719, 0.4064, 0.3923])
+
         expected_slice = np.array([0.27150, 0.14849, 0.15605, 0.26740, 0.16954, 0.18204, 0.31470, 0.26311, 0.24525])
-        assert np.abs(expected_slice - image_slice).max() < 0.001
-
-    # def test_img2img_safety_checker_works(self):
-    #     sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
-    #     sd_pipe.set_progress_bar_config(disable=None)
-
-    #     inputs = self.get_inputs()
-    #     inputs["num_inference_steps"] = 20
-    #     # make sure the safety checker is activated
-    #     inputs["prompt"] = "naked, sex, porn"
-    #     out = sd_pipe(**inputs)
-    #     breakpoint()
-
-    #     assert out.nsfw_content_detected[0], f"Safety checker should work for prompt: {inputs['prompt']}"
-    #     assert np.abs(out.images[0]).sum() < 1e-5  # should be all zeros
+        assert np.abs(expected_slice - image_slice).max() < 1e-3
 
     def test_stable_diffusion_img2img_k_lms(self):
         pipe = StableDiffusionImg2ImgPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
+
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
+
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
+
         assert image.shape == (1, 512, 768, 3)
+        # expected_slice = np.array([0.0389, 0.0346, 0.0415, 0.0290, 0.0218, 0.0210, 0.0408, 0.0567, 0.0271])
         expected_slice = np.array([0.04890, 0.04862, 0.06422, 0.04655, 0.05108, 0.05307, 0.05926, 0.08759, 0.06852])
-        assert np.abs(expected_slice - image_slice).max() < 0.001
+
+        assert np.abs(expected_slice - image_slice).max() < 1e-3
 
     def test_stable_diffusion_img2img_ddim(self):
         pipe = StableDiffusionImg2ImgPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
         pipe.scheduler = DDIMScheduler.from_config(pipe.scheduler.config)
+
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
+
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
+
         assert image.shape == (1, 512, 768, 3)
+        # expected_slice = np.array([0.0593, 0.0607, 0.0851, 0.0582, 0.0636, 0.0721, 0.0751, 0.0981, 0.0781])
         expected_slice = np.array([0.06069, 0.05703, 0.08054, 0.05797, 0.06286, 0.06234, 0.08438, 0.11151, 0.08068])
-        assert np.abs(expected_slice - image_slice).max() < 0.001
+
+        assert np.abs(expected_slice - image_slice).max() < 1e-3
 
     def test_stable_diffusion_img2img_intermediate_state(self):
         number_of_steps = 0
@@ -296,6 +409,7 @@ class StableDiffusionImg2ImgPipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 96)
                 latents_slice = latents[0, -3:, -3:, -1]
+                # expected_slice = np.array([-0.4958, 0.5107, 1.1045, 2.7539, 4.6680, 3.8320, 1.5049, 1.8633, 2.6523])
                 expected_slice = np.array(
                     [
                         0.7650054097175598,
@@ -309,11 +423,13 @@ class StableDiffusionImg2ImgPipelineSlowTests(unittest.TestCase):
                         1.765011191368103,
                     ]
                 )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+
+                assert np.abs(latents_slice.flatten() - expected_slice).max() < 5e-2
             elif step == 2:
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 96)
                 latents_slice = latents[0, -3:, -3:, -1]
+                # expected_slice = np.array([-0.4956, 0.5078, 1.0918, 2.7520, 4.6484, 3.8125, 1.5146, 1.8633, 2.6367])
                 expected_slice = np.array(
                     [
                         0.7580092549324036,
@@ -327,40 +443,171 @@ class StableDiffusionImg2ImgPipelineSlowTests(unittest.TestCase):
                         1.761878490447998,
                     ]
                 )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+
+                assert np.abs(latents_slice.flatten() - expected_slice).max() < 5e-2
 
         callback_fn.has_been_called = False
+
         pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
             "CompVis/stable-diffusion-v1-4", safety_checker=None, paddle_dtype=paddle.float16
         )
+
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-        inputs = self.get_inputs(dtype="float16")
+
+        inputs = self.get_inputs(dtype=paddle.float16)
         pipe(**inputs, callback=callback_fn, callback_steps=1)
         assert callback_fn.has_been_called
         assert number_of_steps == 2
 
+    # def test_stable_diffusion_pipeline_with_sequential_cpu_offloading(self):
+    #     paddle.device.cuda.empty_cache()
+    #     # torch.cuda.reset_max_memory_allocated()
+    #     # torch.cuda.reset_peak_memory_stats()
+
+    #     pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
+    #         "CompVis/stable-diffusion-v1-4", safety_checker=None, paddle_dtype=paddle.float16
+    #     )
+
+    #     pipe.set_progress_bar_config(disable=None)
+    #     pipe.enable_attention_slicing(1)
+    #     pipe.enable_sequential_cpu_offload()
+
+    #     inputs = self.get_inputs(dtype=paddle.float16)
+    #     _ = pipe(**inputs)
+
+    #     mem_bytes = torch.cuda.max_memory_allocated()
+    #     # make sure that less than 2.2 GB is allocated
+    #     assert mem_bytes < 2.2 * 10**9
+
+    # def test_stable_diffusion_pipeline_with_model_offloading(self):
+    #     paddle.device.cuda.empty_cache()
+    #     # torch.cuda.reset_max_memory_allocated()
+    #     # torch.cuda.reset_peak_memory_stats()
+
+    #     inputs = self.get_inputs(dtype=paddle.float16)
+
+    #     # Normal inference
+
+    #     pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
+    #         "CompVis/stable-diffusion-v1-4",
+    #         safety_checker=None,
+    #         paddle_dtype=paddle.float16,
+    #     )
+
+    #     pipe.set_progress_bar_config(disable=None)
+    #     pipe(**inputs)
+    #     mem_bytes = torch.cuda.max_memory_allocated()
+
+    #     # With model offloading
+
+    #     # Reload but don't move to cuda
+    #     pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
+    #         "CompVis/stable-diffusion-v1-4",
+    #         safety_checker=None,
+    #         paddle_dtype=paddle.float16,
+    #     )
+
+    #     paddle.device.cuda.empty_cache()
+    #     # torch.cuda.reset_max_memory_allocated()
+    #     # torch.cuda.reset_peak_memory_stats()
+
+    #     pipe.enable_model_cpu_offload()
+    #     pipe.set_progress_bar_config(disable=None)
+    #     _ = pipe(**inputs)
+    #     mem_bytes_offloaded = torch.cuda.max_memory_allocated()
+
+    #     assert mem_bytes_offloaded < mem_bytes
+    #     for module in pipe.text_encoder, pipe.unet, pipe.vae:
+    #         assert module.device == torch.device("cpu")
+
+    #    def test_img2img_2nd_order(self):
+    #        sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
+    #        sd_pipe.scheduler = HeunDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+    #
+    #        sd_pipe.set_progress_bar_config(disable=None)
+    #
+    #        inputs = self.get_inputs()
+    #        inputs["num_inference_steps"] = 10
+    #        inputs["strength"] = 0.75
+    #        image = sd_pipe(**inputs).images[0]
+    #
+    #        expected_image = load_numpy(
+    #            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/img2img/img2img_heun.npy"
+    #        )
+    #        max_diff = np.abs(expected_image - image).max()
+    #        assert max_diff < 5e-2
+    #
+    #        inputs = self.get_inputs()
+    #        inputs["num_inference_steps"] = 11
+    #        inputs["strength"] = 0.75
+    #        image_other = sd_pipe(**inputs).images[0]
+    #
+    #        mean_diff = np.abs(image - image_other).mean()
+    #
+    #        # images should be very similar
+    #        assert mean_diff < 5e-2
+
     def test_stable_diffusion_img2img_pipeline_multiple_of_8(self):
         init_image = load_image("https://paddlenlp.bj.bcebos.com/data/images/sketch-mountains-input.jpg")
         init_image = init_image.resize((760, 504))
+
         model_id = "CompVis/stable-diffusion-v1-4"
-        pipe = StableDiffusionImg2ImgPipeline.from_pretrained(model_id, safety_checker=None)
+        pipe = StableDiffusionImg2ImgPipeline.from_pretrained(
+            model_id,
+            safety_checker=None,
+        )
+
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
+
         prompt = "A fantasy landscape, trending on artstation"
         generator = paddle.Generator().manual_seed(0)
         output = pipe(
-            prompt=prompt, image=init_image, strength=0.75, guidance_scale=7.5, generator=generator, output_type="np"
+            prompt=prompt,
+            image=init_image,
+            strength=0.75,
+            guidance_scale=7.5,
+            generator=generator,
+            output_type="np",
         )
         image = output.images[0]
+
         image_slice = image[255:258, 383:386, -1]
+
         assert image.shape == (504, 760, 3)
+        # expected_slice = np.array([0.9393, 0.9500, 0.9399, 0.9438, 0.9458, 0.9400, 0.9455, 0.9414, 0.9423])
         expected_slice = np.array([0.7286, 0.7218, 0.7078, 0.7278, 0.7201, 0.7027, 0.7305, 0.7267, 0.7097])
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.05
+
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 5e-2
+
+    def test_img2img_safety_checker_works(self):
+        pass
+        # sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
+
+        # sd_pipe.set_progress_bar_config(disable=None)
+
+        # inputs = self.get_inputs()
+        # inputs["num_inference_steps"] = 20
+        # # make sure the safety checker is activated
+        # inputs["prompt"] = "naked, sex, porn"
+        # out = sd_pipe(**inputs)
+
+        # assert out.nsfw_content_detected[0], f"Safety checker should work for prompt: {inputs['prompt']}"
+        # assert np.abs(out.images[0]).sum() < 1e-5  # should be all zeros
+
+    @require_python39_or_higher
+    def test_img2img_compile(self):
+        seed = 0
+        inputs = self.get_inputs(seed=seed)
+        # Can't pickle a Generator object
+        del inputs["generator"]
+        # inputs["torch_device"] = torch_device
+        inputs["seed"] = seed
+        run_test_in_subprocess(test_case=self, target_func=_test_img2img_compile, inputs=inputs)
 
 
 @nightly
-@require_paddle_gpu
 class StableDiffusionImg2ImgPipelineNightlyTests(unittest.TestCase):
     def tearDown(self):
         super().tearDown()
@@ -383,44 +630,47 @@ class StableDiffusionImg2ImgPipelineNightlyTests(unittest.TestCase):
 
     def test_img2img_pndm(self):
         sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
-        sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
+
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
         expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_1_5_pndm.npy")
         max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 0.001
+        assert max_diff < 1e-3
 
     def test_img2img_ddim(self):
         sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
-        sd_pipe
+
         sd_pipe.set_progress_bar_config(disable=None)
+
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
         expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_1_5_ddim.npy")
         max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 0.001
+        assert max_diff < 1e-3
 
     def test_img2img_lms(self):
         sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
-        sd_pipe
+
         sd_pipe.set_progress_bar_config(disable=None)
+
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
         expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_1_5_lms.npy")
         max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 0.001
+        assert max_diff < 1e-3
 
     def test_img2img_dpm(self):
         sd_pipe = StableDiffusionImg2ImgPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
-        sd_pipe
+
         sd_pipe.set_progress_bar_config(disable=None)
+
         inputs = self.get_inputs()
         inputs["num_inference_steps"] = 30
         image = sd_pipe(**inputs).images[0]
         expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_1_5_dpm.npy")
         max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 0.001
+        assert max_diff < 1e-3
